@@ -211,231 +211,6 @@ size_t mutt_iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
 }
 
 
-/*************************************************************
- * General decoder framework
- * Used in handler.c for converting to mutt's Charset
- */
-
-#define MIN(a,b) (((a) <= (b)) ? (a): (b))
-
-DECODER *mutt_open_decoder (const char *src, const char *dest)
-{
-  DECODER *d = safe_calloc (1, sizeof (DECODER));;
-
-  d->in.size = DECODER_BUFFSIZE;
-  d->out.size = DECODER_BUFFSIZE;
-
-  if (dest && src && (d->cd = mutt_iconv_open (dest, src)) != (iconv_t)-1)
-  {
-    d->_in = &d->in;
-    d->outrepl = mutt_is_utf8 (dest) ? "\357\277\275" : "?";
-  }
-  else
-  {
-    d->just_take_id = 1;
-    d->_in = &d->out;
-  }
-  return d;
-}
-
-void mutt_free_decoder (DECODER **dpp)
-{
-  safe_free ((void **) dpp);
-}
-
-static void _process_data (DECODER *d, short force)
-{
-  if (force) d->forced = 1;
-  
-  if (!d->just_take_id)
-  {
-    const char *ib = d->in.buff;
-    size_t ibl = d->in.used;
-    char *ob = d->out.buff + d->out.used;
-    size_t obl = d->out.size - d->out.used;
-
-    mutt_iconv (d->cd, &ib, &ibl, &ob, &obl, 0, d->outrepl);
-    memmove (d->in.buff, ib, ibl);
-    d->in.used = ibl;
-    d->out.used = d->out.size - obl;
-  }
-}
-
-void mutt_decoder_push (DECODER *d, void *_buff, size_t blen, size_t *taken)
-{
-  if (!_buff || !blen)
-  {
-    _process_data (d, 1);
-    return;
-  }
-
-  if ((*taken = MIN(blen, d->_in->size - d->_in->used)))
-  {
-    memcpy (d->_in->buff + d->_in->used, _buff, *taken);
-    d->_in->used += *taken;
-  }
-}
-
-int mutt_decoder_push_one (DECODER *d, char c)
-{
-  if (d->_in->used == d->_in->size)
-    return -1;
-
-  d->_in->buff[d->_in->used++] = c;
-  return 0;
-}
-
-void mutt_decoder_pop (DECODER *d, void *_buff, size_t blen, size_t *popped)
-{
-  unsigned char *buff = _buff;
-
-  _process_data (d, 0);
-  
-  if ((*popped = MIN (blen, d->out.used)))
-  {
-    memcpy (buff, d->out.buff, *popped);
-    memmove (d->out.buff, d->out.buff + *popped, d->out.used - *popped);
-    d->out.used -= *popped;
-  }
-}
-
-void mutt_decoder_pop_to_state (DECODER *d, STATE *s)
-{
-  char tmp[DECODER_BUFFSIZE];
-  size_t i, l;
-
-  if (s->prefix)
-  {
-    do 
-    {
-      mutt_decoder_pop (d, tmp, sizeof (tmp), &l);
-      for (i = 0; i < l; i++)
-	state_prefix_putc (tmp[i], s);
-    }
-    while (l > 0);
-  }
-  else
-  {
-    do 
-    {
-      mutt_decoder_pop (d, tmp, sizeof (tmp), &l);
-      fwrite (tmp, l, 1, s->fpout);
-    }
-    while (l > 0);
-  }
-}
-
-
-int mutt_recode_file (const char *fname, const char *src, const char *dest)
-{
-  FILE *fp, *tmpfp;
-  char tempfile[_POSIX_PATH_MAX];
-  char buffer[1024];
-  char tmp[1024];
-  int c;
-  int rv = -1;
-  int source_file_is_unchanged = 1;
-
-  size_t lf, lpu, lpo;
-  char *t;
-  DECODER *dec;
-
-  if ((fp = fopen (fname, "r+")) == NULL)
-  {
-    mutt_error (_("Can't open %s: %s."), fname, strerror (errno));
-    return -1;
-  }
-  
-  mutt_mktemp (tempfile);
-  if ((tmpfp = safe_fopen (tempfile, "w+")) == NULL)
-  {
-    mutt_error (_("Can't open %s: %s."), tempfile, strerror (errno));
-    fclose (fp);
-    return -1;
-  }
-
-  dec = mutt_open_decoder (src, dest);
-  
-  while ((lf = fread (buffer, 1, sizeof (buffer), fp)) > 0)
-  {
-    for (t = buffer; lf; t += lpu)
-    {
-      mutt_decoder_push (dec, t, lf, &lpu);
-      lf -= lpu;
-      
-      do
-      {
-	mutt_decoder_pop (dec, tmp, sizeof (tmp), &lpo);
-	if (lpo)
-	{
-	  if (fwrite (tmp, lpo, 1, tmpfp) == EOF)
-	    goto bail;
-	}
-      } 
-      while (lpo);
-    }
-  }
-  if (lf == EOF && !feof(fp))
-  {
-    goto bail;
-  }
-
-  mutt_decoder_push (dec, NULL, 0, NULL);
-  do 
-  {
-    mutt_decoder_pop (dec, tmp, sizeof (tmp), &lpo);
-    if (lpo)
-    {
-      if (fwrite (tmp, lpo, 1, tmpfp) == EOF)
-	goto bail;
-    }
-  }
-  while (lpo);
-
-  mutt_free_decoder (&dec);
-
-  fclose (fp); fp = NULL;
-  rewind (tmpfp);
-
-
-  source_file_is_unchanged = 0;
-
-  /* don't use safe_fopen here - we're just going
-   * to overwrite the old file.
-   */
-  if ((fp = fopen (fname, "w")) == NULL)
-    goto bail;
-  
-  while ((c = fgetc (tmpfp)) != EOF)
-    if (fputc (c, fp) == EOF)
-      goto bail;
-
-  rv = 0;
-  unlink (tempfile);
-  
-bail:
-  if (rv == -1)
-  {
-    if (source_file_is_unchanged)
-    {
-      mutt_error (_("Error while recoding %s. "
-		    "Leave it unchanged."),
-		  fname);
-    }
-    else
-    {
-      mutt_error (_("Error while recoding %s. "
-		    "See %s for recovering your data."),
-		  fname, tempfile);
-    }
-  }
-
-  if (fp) fclose (fp);
-  if (tmpfp) fclose (tmpfp);
-  return rv;
-}
-
-
 /*
  * Convert a string
  * Used in rfc2047.c and rfc2231.c
