@@ -14,7 +14,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 /* Mutt browser support routines */
@@ -66,7 +66,7 @@ int imap_init_browse (char *path, struct browser_state *state)
 
   strfcpy (list_cmd, option (OPTIMAPLSUB) ? "LSUB" : "LIST", sizeof (list_cmd));
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state == IMAP_DISCONNECTED))
@@ -394,7 +394,7 @@ static int get_namespace (IMAP_DATA *idata, char *nsbuf, int nsblen,
   mutt_socket_write (idata->conn, buf);
   do 
   {
-    if (mutt_socket_read_line_d (buf, sizeof (buf), idata->conn) < 0)
+    if (mutt_socket_readln (buf, sizeof (buf), idata->conn) < 0)
       return -1;
 
     if (buf[0] == '*') 
