@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (C) 1996-9 Brandon Long <blong@fiction.net>
- * Copyright (C) 1999 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 1999-2000 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -101,9 +101,11 @@ int imap_code (const char *s)
 }
 
 /* imap_exec: execute a command, and wait for the response from the server.
- * Also, handle untagged responses
- * If flags == IMAP_OK_FAIL, then the calling procedure can handle a response 
- * failing, this is used for checking for a mailbox on append and login
+ * Also, handle untagged responses.
+ * Flags:
+ *   IMAP_CMD_FAIL_OK: the calling procedure can handle failure. This is used
+ *     for checking for a mailbox on append and login
+ *   IMAP_CMD_PASS: command contains a password. Suppress logging.
  * Return 0 on success, -1 on Failure, -2 on OK Failure
  */
 int imap_exec (char* buf, size_t buflen, IMAP_DATA* idata, const char* cmd,
@@ -111,7 +113,7 @@ int imap_exec (char* buf, size_t buflen, IMAP_DATA* idata, const char* cmd,
 {
   char* out;
   int outlen;
-  char seq[8];
+  char seq[SEQLEN+1];
 
   /* create sequence for command */
   imap_make_sequence (seq, sizeof (seq));
@@ -120,17 +122,18 @@ int imap_exec (char* buf, size_t buflen, IMAP_DATA* idata, const char* cmd,
   out = (char*) safe_malloc (outlen);
   snprintf (out, outlen, "%s %s\r\n", seq, cmd);
 
-  mutt_socket_write (idata->conn, out);
+  mutt_socket_write_d (idata->conn, out,
+    flags & IMAP_CMD_PASS ? IMAP_LOG_PASS : IMAP_LOG_CMD);
 
   safe_free ((void**) &out);
 
   do
   {
-    if (mutt_socket_read_line_d (buf, buflen, idata->conn) < 0)
-      return (-1);
+    if (mutt_socket_readln (buf, buflen, idata->conn) < 0)
+      return -1;
 
     if (buf[0] == '*' && imap_handle_untagged (idata, buf) != 0)
-      return (-1);
+      return -1;
   }
   while (mutt_strncmp (buf, seq, SEQLEN) != 0);
 
@@ -140,21 +143,23 @@ int imap_exec (char* buf, size_t buflen, IMAP_DATA* idata, const char* cmd,
   {
     char *pc;
 
-    if (flags == IMAP_OK_FAIL)
-      return (-2);
-    dprint (1, (debugfile, "imap_exec(): command failed: %s\n", buf));
+    if (flags & IMAP_CMD_FAIL_OK)
+      return -2;
+
+    dprint (1, (debugfile, "imap_exec: command failed: %s\n", buf));
     pc = buf + SEQLEN;
     SKIPWS (pc);
     pc = imap_next_word (pc);
     mutt_error (pc);
     sleep (1);
-    return (-1);
+
+    return -1;
   }
 
   return 0;
 }
 
-/* imap_handle_untagged: fallback parser for otherwise unhandled messages */
+/* imap_handle_untagged: fallback parser for otherwise unhandled messages. */
 int imap_handle_untagged (IMAP_DATA *idata, char *s)
 {
   char *pn;
@@ -257,9 +262,10 @@ int imap_handle_untagged (IMAP_DATA *idata, char *s)
     idata->status = IMAP_BYE;
     if (idata->state == IMAP_SELECTED)
       mx_fastclose_mailbox (idata->selected_ctx);
-    mutt_socket_close_connection (idata->conn);
+    mutt_socket_close (idata->conn);
     idata->state = IMAP_DISCONNECTED;
-    return (-1);
+
+    return -1;
   }
   else if (option (OPTIMAPSERVERNOISE) && (mutt_strncasecmp ("NO", s, 2) == 0))
   {
