@@ -70,12 +70,6 @@ int imap_delete_mailbox (CONTEXT* ctx, char* mailbox)
   return 0;
 }
 
-void imap_set_logout (CONTEXT *ctx)
-{
-  if (CTX_DATA)
-    CTX_DATA->status = IMAP_LOGOUT;
-}
-
 /* imap_parse_date: date is of the form: DD-MMM-YYYY HH:MM:SS +ZZzz */
 time_t imap_parse_date (char *s)
 {
@@ -133,9 +127,10 @@ int imap_read_bytes (FILE *fp, CONNECTION *conn, long bytes)
 
   for (pos = 0; pos < bytes; )
   {
-    len = mutt_socket_read_line (buf, sizeof (buf), conn);
+    len = mutt_socket_readln_d (buf, sizeof (buf), conn, IMAP_LOG_HDR);
     if (len < 0)
-      return (-1);
+      return -1;
+
     pos += len;
     fputs (buf, fp);
     fputs ("\n", fp);
@@ -218,7 +213,7 @@ int imap_reopen_mailbox (CONTEXT *ctx, int *index_hint)
 
   do
   {
-    if (mutt_socket_read_line_d (buf, sizeof (buf), CTX_DATA->conn) < 0)
+    if (mutt_socket_readln (buf, sizeof (buf), CTX_DATA->conn) < 0)
       break;
 
     if (buf[0] == '*')
@@ -359,7 +354,7 @@ static int imap_get_delim (IMAP_DATA *idata, CONNECTION *conn)
 
   do 
   {
-    if (mutt_socket_read_line_d (buf, sizeof (buf), conn) < 0)
+    if (mutt_socket_readln (buf, sizeof (buf), conn) < 0)
     {
       return (-1);
     }
@@ -427,15 +422,16 @@ int imap_open_connection (IMAP_DATA *idata, CONNECTION *conn)
 {
   char buf[LONG_STRING];
 
-  if (mutt_socket_open_connection (conn) < 0)
+  if (mutt_socket_open (conn) < 0)
     return -1;
 
   idata->state = IMAP_CONNECTED;
 
-  if (mutt_socket_read_line_d (buf, sizeof (buf), conn) < 0)
+  if (mutt_socket_readln (buf, sizeof (buf), conn) < 0)
   {
-    mutt_socket_close_connection (conn);
+    mutt_socket_close (conn);
     idata->state = IMAP_DISCONNECTED;
+
     return -1;
   }
 
@@ -444,7 +440,7 @@ int imap_open_connection (IMAP_DATA *idata, CONNECTION *conn)
     if (imap_check_capabilities(idata) != 0 
 	|| imap_authenticate (idata, conn) != 0)
     {
-      mutt_socket_close_connection (conn);
+      mutt_socket_close (conn);
       idata->state = IMAP_DISCONNECTED;
       return -1;
     }
@@ -453,7 +449,7 @@ int imap_open_connection (IMAP_DATA *idata, CONNECTION *conn)
   {
     if (imap_check_capabilities(idata) != 0)
     {
-      mutt_socket_close_connection (conn);
+      mutt_socket_close (conn);
       idata->state = IMAP_DISCONNECTED;
       return -1;
     }
@@ -461,7 +457,7 @@ int imap_open_connection (IMAP_DATA *idata, CONNECTION *conn)
   else
   {
     imap_error ("imap_open_connection()", buf);
-    mutt_socket_close_connection (conn);
+    mutt_socket_close (conn);
     idata->state = IMAP_DISCONNECTED;
     return -1;
   }
@@ -535,7 +531,7 @@ int imap_open_mailbox (CONTEXT *ctx)
   IMAP_DATA *idata;
   char buf[LONG_STRING];
   char bufout[LONG_STRING];
-  char seq[16];
+  char seq[SEQLEN+1];
   int count = 0;
   int n;
   IMAP_MBOX mx;
@@ -546,7 +542,7 @@ int imap_open_mailbox (CONTEXT *ctx)
     return -1;
   }
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state != IMAP_AUTHENTICATED))
@@ -557,12 +553,12 @@ int imap_open_mailbox (CONTEXT *ctx)
       /* We need to create a new connection, the current one isn't useful */
       idata = safe_calloc (1, sizeof (IMAP_DATA));
 
-      conn = mutt_socket_select_connection (&mx, 1);
+      conn = mutt_socket_find (&mx, 1);
       conn->data = idata;
       idata->conn = conn;
     }
     if (imap_open_connection (idata, conn))
-      return (-1);
+      return -1;
   }
   ctx->data = (void *) idata;
 
@@ -595,7 +591,7 @@ int imap_open_mailbox (CONTEXT *ctx)
   {
     char *pc;
     
-    if (mutt_socket_read_line_d (buf, sizeof (buf), conn) < 0)
+    if (mutt_socket_readln (buf, sizeof (buf), conn) < 0)
       break;
 
     if (buf[0] == '*')
@@ -650,6 +646,7 @@ int imap_open_mailbox (CONTEXT *ctx)
     ctx->readonly = 1;
   }
 
+#ifdef DEBUG
   /* dump the mailbox flags we've found */
   if (debuglevel > 2)
   {
@@ -670,6 +667,7 @@ int imap_open_mailbox (CONTEXT *ctx)
       dprint (3, (debugfile, "\n"));
     }
   }
+#endif
 
   if (!imap_code (buf))
   {
@@ -725,7 +723,7 @@ int imap_select_mailbox (CONTEXT* ctx, const char* path)
     return -1;
 
   /* and that it's on the same server as the current folder */
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   if (!CTX_DATA || !CONN_DATA || (CTX_DATA->conn != CONN_DATA->conn))
   {
     dprint(2, (debugfile,
@@ -759,7 +757,7 @@ int imap_open_mailbox_append (CONTEXT *ctx)
 
   ctx->magic = M_IMAP;
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state == IMAP_DISCONNECTED))
@@ -794,30 +792,27 @@ int imap_open_mailbox_append (CONTEXT *ctx)
   }
   else
   {
-    /* STATUS not supported
-     * The thing to do seems to be:
-     *  - Open a *new* IMAP session, select, and then close it. Report the
-     * error if the mailbox did not exist. */
+    /* STATUS not supported */
     mutt_message _("Unable to append to IMAP mailboxes at this server");
+
     return -1;
   }
 
-  r = imap_exec (buf, sizeof (buf), idata, buf, IMAP_OK_FAIL);
+  r = imap_exec (buf, sizeof (buf), idata, buf, IMAP_CMD_FAIL_OK);
   if (r == -2)
   {
     /* command failed cause folder doesn't exist */
     snprintf (buf, sizeof (buf), _("Create %s?"), mailbox);
     if (option (OPTCONFIRMCREATE) && mutt_yesorno (buf, 1) < 1)
-      return (-1);
+      return -1;
 
     if (imap_create_mailbox (ctx, mailbox) < 0)
-      return (-1);
+      return -1;
   }
   else if (r == -1)
-  {
     /* Hmm, some other failure */
     return -1;
-  }
+
   return 0;
 }
 
@@ -836,15 +831,14 @@ int imap_close_connection (CONTEXT *ctx)
     mutt_socket_write (CTX_DATA->conn, buf);
     do
     {
-      if (mutt_socket_read_line_d (buf, sizeof (buf), CTX_DATA->conn) < 0)
+      if (mutt_socket_readln (buf, sizeof (buf), CTX_DATA->conn) < 0)
 	break;
     }
     while (mutt_strncmp (seq, buf, SEQLEN) != 0);
     mutt_clear_error ();
   }
-  mutt_socket_close_connection (CTX_DATA->conn);
+  mutt_socket_close (CTX_DATA->conn);
   CTX_DATA->state = IMAP_DISCONNECTED;
-  CTX_DATA->conn->uses = 0;
   CTX_DATA->conn->data = NULL;
   return 0;
 }
@@ -1202,7 +1196,7 @@ int imap_mailbox_check (char *path, int new)
   if (imap_parse_path (path, &mx))
     return -1;
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state == IMAP_DISCONNECTED))
@@ -1258,7 +1252,7 @@ int imap_mailbox_check (char *path, int new)
 
   do 
   {
-    if (mutt_socket_read_line_d (buf, sizeof (buf), conn) < 0)
+    if (mutt_socket_readln (buf, sizeof (buf), conn) < 0)
       return -1;
 
     if (buf[0] == '*') 
@@ -1293,9 +1287,6 @@ int imap_mailbox_check (char *path, int new)
 
   imap_cmd_finish (seq, idata);
 
-  /* what does this do? */
-  conn->uses--;
-
   return msgcount;
 }
 
@@ -1307,10 +1298,9 @@ int imap_parse_list_response(CONNECTION *conn, char *buf, int buflen,
   long bytes;
 
   *name = NULL;
-  if (mutt_socket_read_line_d (buf, buflen, conn) < 0)
-  {
-    return (-1);
-  }
+
+  if (mutt_socket_readln (buf, buflen, conn) < 0)
+    return -1;
 
   if (buf[0] == '*')
   {
@@ -1356,10 +1346,10 @@ int imap_parse_list_response(CONNECTION *conn, char *buf, int buflen,
 	int len;
 	
 	if (imap_get_literal_count(buf, &bytes) < 0)
-	  return (-1);
-	len = mutt_socket_read_line (buf, buflen, conn);
+	  return -1;
+	len = mutt_socket_readln (buf, buflen, conn);
 	if (len < 0)
-	  return (-1);
+	  return -1;
 	*name = buf;
       }
       else
@@ -1368,10 +1358,11 @@ int imap_parse_list_response(CONNECTION *conn, char *buf, int buflen,
     else
     {
       if (imap_handle_untagged (idata, buf) != 0)
-	return (-1);
+	return -1;
     }
   }
-  return (0);
+
+  return 0;
 }
 
 int imap_subscribe (char *path, int subscribe)
@@ -1385,7 +1376,7 @@ int imap_subscribe (char *path, int subscribe)
   if (imap_parse_path (path, &mx))
     return (-1);
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state == IMAP_DISCONNECTED))
@@ -1441,7 +1432,7 @@ int imap_complete(char* dest, size_t dlen, char* path) {
     return -1;
   }
 
-  conn = mutt_socket_select_connection (&mx, 0);
+  conn = mutt_socket_find (&mx, 0);
   idata = CONN_DATA;
 
   /* don't open a new socket just for completion */
